@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package App::Cronjob 1.200013;
+package App::Cronjob 1.200014;
 # ABSTRACT: wrap up programs to be run as cron jobs
 
 use Digest::MD5 qw(md5_hex);
@@ -263,7 +263,7 @@ END_TEMPLATE
 }
 
 {
-  package App::Cronjob::Exception 1.200013;
+  package App::Cronjob::Exception 1.200014;
 
   sub new {
     my ($class, $type, $text, $extra) = @_;
@@ -285,17 +285,17 @@ App::Cronjob - wrap up programs to be run as cron jobs
 
 =head1 VERSION
 
-version 1.200013
+version 1.200014
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 SEE INSTEAD
 
